@@ -1,24 +1,29 @@
 #!/bin/bash -xe
-[[ -d exported-artifacts ]] \
-|| mkdir -p exported-artifacts
 
-[[ -d tmp.repos ]] \
-|| mkdir -p tmp.repos
+# cleanup leftovers from previous builds
+rm -rf exported-artifacts
+rm -rf tmp.repos
 
-SUFFIX=".$(date -u +%Y%m%d%H%M%S).git$(git rev-parse --short HEAD)"
+mkdir -p exported-artifacts
+mkdir -p tmp.repos
+
+if git describe --exact-match --tags --match "[0-9]*" > /dev/null 2>&1 ; then
+    SUFFIX=""
+else
+    SUFFIX=".$(date -u +%Y%m%d%H%M%S).git$(git rev-parse --short HEAD)"
+fi
 
 ./autogen.sh
 ./configure \
     --with-dist
 make dist
 
-# We build the depdendencies for windows only on latest fedora.
-# Do not check %dist but just try to get them. Exit cleanly if missing.
-if yum-builddep -y ovirt-guest-agent-windows.spec; then
+if ! rpm --eval "%dist" | grep -qFi 'el6'; then
+    yum-builddep -y ovirt-guest-agent-windows.spec
     rpmbuild \
         -D "_topdir $PWD/tmp.repos" \
         -D "_sourcedir $PWD" \
-        -D "release_suffix ${SUFFIX}" \
+        ${SUFFIX:+-D "release_suffix ${SUFFIX}"} \
         -ba ovirt-guest-agent-windows.spec
 fi
 
@@ -27,16 +32,14 @@ if rpm --eval "%dist" | grep -qFi 'el6'; then
     rpmbuild \
         -D "_topdir $PWD/tmp.repos" \
         -D "_sourcedir $PWD" \
-        -D "release_suffix ${SUFFIX}" \
+        ${SUFFIX:+-D "release_suffix ${SUFFIX}"} \
         -ba ovirt-guest-agent.rhel6.spec
-elif rpm --eval "%dist" | grep -qFi 'el7'; then
-    echo "TODO"
 else
     yum-builddep -y ovirt-guest-agent.spec
     rpmbuild \
         -D "_topdir $PWD/tmp.repos" \
         -D "_sourcedir $PWD" \
-        -D "release_suffix ${SUFFIX}" \
+        ${SUFFIX:+-D "release_suffix ${SUFFIX}"} \
         -ba ovirt-guest-agent.spec
 fi
 
