@@ -111,24 +111,33 @@ def _filter_object(obj):
     return filt(obj)
 
 
+def get_vports(prefix):
+    return (os.path.join(prefix, 'ovirt-guest-agent.0'),
+            os.path.join(prefix, 'com.redhat.rhevm.vdsm'))
+
+
 class VirtIoStream(object):
     # Python on Windows 7 returns 'Microsoft' rather than 'Windows' as
     # documented.
     is_windows = platform.system() in ['Windows', 'Microsoft']
     is_test = False
 
-    def __init__(self, vport_name):
+    def __init__(self, vport_prefix):
         if self.is_test:
             from test_port import get_test_port
-            self._vport = get_test_port(vport_name)
+            self._vport = get_test_port(vport_prefix)
             self._read = self._vport.read
             self._write = self._vport.write
         elif self.is_windows:
             from WinFile import WinFile
-            self._vport = WinFile(vport_name)
+            self._vport = WinFile(get_vports(vport_prefix))
             self._read = self._vport.read
             self._write = self._vport.write
         else:
+            current_port, legacy_port = get_vports(vport_prefix)
+            vport_name = current_port
+            if os.path.exists(legacy_port):
+                vport_name = legacy_port
             self._vport = os.open(vport_name, os.O_RDWR)
             self._read = self._os_read
             self._write = self._os_write
@@ -199,34 +208,3 @@ class VirtIoChannel:
             written = self._stream.write(message)
             logging.debug("Written %s" % message[:written])
             message = message[written:]
-
-
-def _create_vio():
-    if (platform.system() == 'Windows') or (platform.system() == 'Microsoft'):
-        vport_name = '\\\\.\\Global\\com.redhat.rhevm.vdsm'
-    else:
-        vport_name = '/dev/virtio-ports/com.redhat.rhevm.vdsm'
-    return VirtIoChannel(vport_name)
-
-
-def _test_write():
-    vio = _create_vio()
-    vio.write('network-interfaces',
-              {'interfaces': [{
-                  'name': 'eth0',
-                  'inet': ['10.0.0.2'],
-                  'inet6': ['fe80::213:20ff:fef5:f9d6'],
-                  'hw': '00:1a:4a:23:10:00'}]})
-    vio.write('applications', {'applications': ['kernel-2.6.32-131.4.1.el6',
-                                                'rhev-agent-2.3.11-1.el6']})
-
-
-def _test_read():
-    vio = _create_vio()
-    line = vio.read()
-    while line:
-        print line
-        line = vio.read()
-
-if __name__ == "__main__":
-    _test_read()
